commit:     d88cf4746c0fe891087a79d630e9d8181c7cbd04
Author:     Brian Dolbec <dolsen <AT> gentoo <DOT> org>
AuthorDate: Mon Feb  2 18:30:31 2015 +0000
Commit:     Brian Dolbec <dolsen <AT> gentoo <DOT> org>
CommitDate: Mon Feb  2 18:34:02 2015 +0000
URL:        
http://sources.gentoo.org/gitweb/?p=proj/portage.git;a=commit;h=d88cf474

portage/repository/config.py: Deprecate make.conf SYNC variable bug 538512

Newer mirrorselect modifies repos.conf, no need for this anymore.

---
 pym/portage/repository/config.py | 14 ++++++++++----
 1 file changed, 10 insertions(+), 4 deletions(-)

diff --git a/pym/portage/repository/config.py b/pym/portage/repository/config.py
index f80742e..6d79452 100644
--- a/pym/portage/repository/config.py
+++ b/pym/portage/repository/config.py
@@ -606,10 +606,12 @@ class RepoConfigLoader(object):
                if "PORTAGE_REPOSITORIES" in settings:
                        portdir = ""
                        portdir_overlay = ""
+                       # depercated portdir_sync
                        portdir_sync = ""
                else:
                        portdir = settings.get("PORTDIR", "")
                        portdir_overlay = settings.get("PORTDIR_OVERLAY", "")
+                       # depercated portdir_sync
                        portdir_sync = settings.get("SYNC", "")
 
                try:
@@ -734,11 +736,15 @@ class RepoConfigLoader(object):
                        # This happens if main-repo has been set in repos.conf.
                        prepos[main_repo].priority = -1000
 
                # Backward compatible SYNC support for mirrorselect.
mirrorselect.
+               # Feb. 2, 2015.  Version 2.0.16
                if portdir_sync and main_repo is not None:
-                       if portdir_sync.startswith("rsync://"):
-                               prepos[main_repo].sync_uri = portdir_sync
-                               prepos[main_repo].sync_type = "rsync"
+                       writemsg(_("!!! SYNC setting found in make.conf.\n    "
+                               "This setting is Deprecated and no longer used. 
 "
+                               "Please ensure your 'sync-type' and 'sync-uri' 
are set correctly"
+                               " in repos.conf/gentoo.conf\n"),
+                               noiselevel=-1)
+
 
                # Include repo.name in sort key, for predictable sorting
                # even when priorities are equal.
@@ -734,11 +736,15 @@ class RepoConfigLoader(object):
                        prepos[main_repo].priority = -1000
 
-               # Backward compatible SYNC support for mirrorselect.
+               # DEPRECATED Backward compatible SYNC support for old 
mirrorselect.

Reply via email to